﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.IO;

namespace howto_copy_folder_structure
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            clbSubfolders.CheckOnClick = true;

            txtFromFolder.Text =
                ResolveFolderName(Application.StartupPath, @"..\..");
            txtToFolder.Text =
                ResolveFolderName(Application.StartupPath, @"..\..\TestFolder");
        }

        private string ResolveFolderName(string path1, string path2)
        {
            DirectoryInfo dir_info = new DirectoryInfo(
                Path.Combine(path1, path2));
            return dir_info.FullName;
        }

        private void btnListSubfolders_Click(object sender, EventArgs e)
        {
            clbSubfolders.Items.Clear();

            string from_folder = txtFromFolder.Text;
            foreach (string subfolder in Directory.GetDirectories(from_folder))
            {
                clbSubfolders.Items.Add(new DirNameInfo(subfolder));
            }
            clbSubfolders.CheckAll();
        }

        private void btnMakeSubfolders_Click(object sender, EventArgs e)
        {
            string to_folder = txtToFolder.Text;
            int num_created = 0;
            foreach (DirNameInfo dir in clbSubfolders.CheckedItems)
            {
                if (!CreateSubfolder(to_folder, dir)) break;
                num_created++;
            }
            MessageBox.Show(string.Format("Created {0} folders",
                num_created));
        }

        // Return true if we should continue.
        private bool CreateSubfolder(string to_folder, DirNameInfo dir)
        {
            string path = Path.Combine(to_folder, dir.Name);
            try
            {
                if (Directory.Exists(path))
                {
                    if (MessageBox.Show(string.Format(
                        "Subfolder {0} already exists.\n\nContinue?",
                        path), "Folder Exists", MessageBoxButtons.YesNo)
                            == DialogResult.No)
                        return false;
                }

                Directory.CreateDirectory(path);
                Console.WriteLine("Created " + path);
            }
            catch (Exception ex)
            {
                if (MessageBox.Show(string.Format(
                    "Error creating folder {0}.\n{1}\n\nContinue?",
                        path, ex.Message)) == DialogResult.No)
                    return false;
            }
            return true;
        }
    }
}
